Crate interactors

Crate interactors 

Structs

AddCommand
A simple example command that adds two numbers
CommandInvoker
A command invoker that can execute any command
MultiplyCommand
A simple example command that multiplies two numbers

Traits

Command
The Command trait defines the interface for all commands. Each command must implement an execute method that performs the action.